@@ -89,6 +89,7 @@ static QRect getCommandBarBoundingRect(KCommandBar *commandBar)
 // BEGIN CommandBarFilterModel
 class CommandBarFilterModel final : public QSortFilterProxyModel
 {
+    Q_OBJECT
 public:
     CommandBarFilterModel(QObject *parent = nullptr)
         : QSortFilterProxyModel(parent)
@@ -156,13 +157,14 @@ private:
 
 class CommandBarStyleDelegate final : public QStyledItemDelegate
 {
+    Q_OBJECT
 public:
     CommandBarStyleDelegate(QObject *parent = nullptr)
         : QStyledItemDelegate(parent)
     {
     }
 
-    /**
+    /*
      * Paints a single item's text
      */
     static void
@@ -195,7 +197,7 @@ public:
 
         textLayout.endLayout();
 
-        /**
+        /*
          * get "Y" so that we can properly V-Center align the text in row
          */
         const int y = QStyle::alignedRect(Qt::LeftToRight, Qt::AlignVCenter, textLayout.boundingRect().size().toSize(), rect).y();
@@ -209,7 +211,7 @@ public:
     {
         painter->save();
 
-        /**
+        /*
          * Draw everything, (widget, icon etc) except the text
          */
         QStyleOptionViewItem option = opt;
@@ -253,7 +255,7 @@ public:
         fmt.setForeground(option.palette.link());
         fmt.setFontWeight(QFont::Bold);
 
-        /**
+        /*
          * Highlight matches from fuzzy matcher
          */
         const auto fmtRanges = KFuzzyMatcher::matchedRanges(m_filterString, str);
@@ -282,6 +284,7 @@ private:
 
 class ShortcutStyleDelegate final : public QStyledItemDelegate
 {
+    Q_OBJECT
 public:
     ShortcutStyleDelegate(QObject *parent = nullptr)
         : QStyledItemDelegate(parent)
@@ -464,7 +467,7 @@ public:
     KCommandBarModel m_model;
     CommandBarFilterModel m_proxyModel;
 
-    /**
+    /*
      * selects first item in treeview
      */
     void reselectFirst()
@@ -473,7 +476,7 @@ public:
         m_treeView.setCurrentIndex(index);
     }
 
-    /**
+    /*
      * blocks signals before clearing line edit to ensure
      * we don't trigger filtering / sorting
      */
@@ -512,7 +515,7 @@ void KCommandBarPrivate::slotReturnPressed(KCommandBar *q)
 
             m_model.refresh({ag});
             reselectFirst();
-            /**
+            /*
              *  We want the "textChanged" signal here
              *  so that proxy model triggers filtering again
              *  so don't use d->clearLineEdit()
@@ -658,7 +661,7 @@ KCommandBar::KCommandBar(QWidget *parent)
     }
 }
 
-/**
+/*
  * Destructor defined here to make unique_ptr work
  */
 KCommandBar::~KCommandBar()
@@ -734,6 +737,11 @@ bool KCommandBar::eventFilter(QObject *obj, QEvent *event)
         }
 
         if (keyEvent->key() == Qt::Key_Escape) {
+            if (event->type() == QEvent::ShortcutOverride) {
+                // Override the shortcut. We will get KeyPress event for Key_Escape
+                // later and then hide
+                return true;
+            }
             hide();
             deleteLater();
             return true;
@@ -757,4 +765,5 @@ bool KCommandBar::eventFilter(QObject *obj, QEvent *event)
 }
 // END KCommandBar
 
+#include "kcommandbar.moc"
 #include "moc_kcommandbar.cpp"
